@@ -25,10 +25,10 @@ class DictObject(tp.MutableMapping[str, T]):
         return item in self.__data
 
     def __str__(self) -> str:
-        return 'DictObject(%s)' % (str(self.__data), )
+        return 'DictObject(%s)' % (str(self.__data),)
 
     def __repr__(self) -> str:
-        return 'DictObject(%s)' % (repr(self.__data), )
+        return 'DictObject(%s)' % (repr(self.__data),)
 
     def setdefault(self, k: str, default: tp.Any) -> tp.Any:
         try:
@@ -120,13 +120,13 @@ class DictObject(tp.MutableMapping[str, T]):
         except KeyError:
             return v
 
-    def keys(self):
+    def keys(self) -> tp.Iterator[str]:
         return self.__data.keys()
 
-    def values(self):
+    def values(self) -> tp.Iterator[T]:
         return self.__data.values()
 
-    def items(self):
+    def items(self) -> tp.Iterator[tp.Tuple[str, T]]:
         return self.__data.items()
 
 
@@ -145,4 +145,4 @@ def apply_dict_object(v: tp.Union[tp.Any, tp.Dict[str, T]]) -> tp.Union[DictObje
             k: apply_dict_object(val) for k, val in v.items()
         })
     else:
-        return v
\ No newline at end of file
+        return v
