@@ -1,9 +1,10 @@
-import typing as tp
-import re
-import os
 import codecs
+import os
+import re
+import typing as tp
 
-__all__ = ['read_re_sub_and_write', 'find_files', 'split', 'read_in_file', 'write_to_file']
+__all__ = ['read_re_sub_and_write', 'find_files', 'split', 'read_in_file', 'write_to_file',
+           'write_out_file_if_different', 'make_noncolliding_name']
 
 SEPARATORS = {'\\', '/'}
 SEPARATORS.add(os.path.sep)
@@ -17,6 +18,32 @@ def _has_separator(path: str) -> bool:
     return any(map(lambda x: x in path, SEPARATORS))
 
 
+def make_noncolliding_name(path: str,
+                           exists_checker: tp.Callable[[str], bool] = os.path.exists) -> str:
+    """
+    Try to make a noncolliding name in such a way that .1, .2, .3, and so on will be appended
+    to the file name right before the extension (yielding test.1.txt) or at the end of the file
+    name if the extension isn't present
+
+    :param path: path of the file that has not to exist
+    :param exists_checker: a callable to check with if the file exists
+    :return: name mutated in such a way that exists_checker returned False on it
+    """
+    path, filename = os.path.split(path)
+    if '.' in filename:
+        *filename, extension = filename.split('.')
+        filename = '.'.join(filename)
+        extension = '.'+extension
+    else:
+        extension = ''
+    addition = ''
+    addition_counter = 0
+    while exists_checker(os.path.join(path, filename+addition+extension)):
+        addition_counter += 1
+        addition = '.' + str(addition_counter)
+    return os.path.join(path, filename+addition+extension)
+
+
 def split(path: str) -> tp.List[str]:
     """
     An exact reverse of os.path.join
@@ -31,7 +58,8 @@ def split(path: str) -> tp.List[str]:
     return data
 
 
-def write_to_file(path: str, data: tp.Union[bytes, str], encoding: tp.Optional[str] = None) -> None:
+def write_to_file(path: str, data: tp.Union[bytes, str],
+                  encoding: tp.Optional[str] = None) -> None:
     """
     Write provided content as a file, applying given encoding (or data is bytes, if none given)
 
@@ -52,8 +80,8 @@ def write_to_file(path: str, data: tp.Union[bytes, str], encoding: tp.Optional[s
 
 def read_in_file(path: str, encoding: tp.Optional[str] = None) -> tp.Union[bytes, str]:
     """
-    Opens a file for reading, reads it in, converts to given encoding (or returns as bytes if not given),
-    and closes it.
+    Opens a file for reading, reads it in, converts to given encoding (or returns as bytes
+    if not given), and closes it.
     """
     if encoding is None:
         file = open(path, 'rb')
@@ -104,8 +132,9 @@ def find_files(path: str, wildcard: str = r'(.*)',
     Look at given path's files and all subdirectories and return an iterator of
     file names (paths included) that conform to given wildcard.
 
-    Note that wildcard is only applied to the file name if apply_wildcard_to_entire_path is False,
-    else the wildcard is applied to entire path (including the application of prefix_with!).
+    Note that wildcard is only applied to the file name if apply_wildcard_to_entire_path
+    is False, else the wildcard is applied to entire path (including the application of
+    prefix_with!).
 
     Files will be additionally prefixed with path, but only if prefix_with_path is True
 
@@ -124,7 +153,8 @@ def find_files(path: str, wildcard: str = r'(.*)',
     for filename in os.listdir(path):
         if scan_subdirectories and os.path.isdir(os.path.join(path, filename)):
             new_prefix = _cond_join(prefix_with, filename)
-            yield from find_files(os.path.join(path, filename), wildcard, prefix_with=new_prefix,
+            yield from find_files(os.path.join(path, filename), wildcard,
+                                  prefix_with=new_prefix,
                                   prefix_with_path=False)
         else:
             if apply_wildcard_to_entire_path:
@@ -133,3 +163,31 @@ def find_files(path: str, wildcard: str = r'(.*)',
                 fn_path = filename
             if re.match(wildcard, fn_path):
                 yield _cond_join(prefix_with, filename)
+
+
+def write_out_file_if_different(path: str, data: tp.Union[bytes, str],
+                                encoding: tp.Optional[str] = None) -> bool:
+    """
+    Syntactic sugar for
+
+    >>> try:
+    >>>     if read_in_file(path, encoding) != data:
+    >>>         write_to_file(path, data, encoding)
+    >>>         return True
+    >>>     else:
+    >>>         return False
+    >>> except OSError:
+    >>>     write_to_file(path, data, encoding)
+    >>>     return True
+
+    :returns: if write has happened
+    """
+    try:
+        if read_in_file(path, encoding) != data:
+            write_to_file(path, data, encoding)
+            return True
+        else:
+            return False
+    except OSError:
+        write_to_file(path, data, encoding)
+        return True
