@@ -2,12 +2,12 @@ import itertools
 import threading
 import typing as tp
 
-from .metric_types import METRIC_NAMES_TO_CLASSES, MetricLevel, Metric, DEBUG, DISABLED, \
-    INHERIT, RUNTIME
-from .data import MetricDataCollection, MetricData
 from satella.exceptions import MetricAlreadyExists
 from .aggregate import AggregateMetric
+from .data import MetricDataCollection, MetricData
 from .labeled import LabeledMetric
+from .metric_types import METRIC_NAMES_TO_CLASSES, MetricLevel, Metric, DEBUG, DISABLED, \
+    INHERIT, RUNTIME
 
 __all__ = ['getMetric', 'MetricLevel', 'MetricDataCollection',
            'MetricData', 'Metric', 'DISABLED', 'DEBUG', 'INHERIT', 'RUNTIME',
@@ -17,6 +17,16 @@ metrics = {}
 metrics_lock = threading.Lock()
 
 
+def adjust_metric_level_for_root(metric_level: tp.Optional[MetricLevel],
+                                 metric_level_to_set_for_children: tp.Optional[MetricLevel]):
+    if metric_level is None:
+        return MetricLevel.RUNTIME
+    elif metric_level_to_set_for_children == MetricLevel.INHERIT:
+        return MetricLevel.RUNTIME
+    else:
+        return metric_level_to_set_for_children
+
+
 # noinspection PyPep8Naming
 def getMetric(metric_name: str = '',
               metric_type: str = 'base',
@@ -49,14 +59,11 @@ def getMetric(metric_name: str = '',
             tentative_name = '.'.join(name[:name_index])
             if tentative_name not in metrics:
                 if tentative_name == '':
-                    # initialize the root metric
-                    if metric_level is None:
-                        metric_level_to_set_for_root = MetricLevel.RUNTIME
-                    elif metric_level_to_set_for_children == MetricLevel.INHERIT:
-                        metric_level_to_set_for_root = MetricLevel.RUNTIME
-                    else:
-                        metric_level_to_set_for_root = metric_level_to_set_for_children
-                    metric = Metric('', None, metric_level_to_set_for_root, **kwargs)
+                    metric = Metric('',
+                                    None,
+                                    adjust_metric_level_for_root(metric_level,
+                                                                 metric_level_to_set_for_children),
+                                    **kwargs)
                     metric.level = MetricLevel.RUNTIME
                     root_metric = metric
                 elif metric_name == tentative_name:
