@@ -1,12 +1,37 @@
-import inspect
-import typing as tp
-import time
 import copy
+import inspect
+import time
+import typing as tp
 from concurrent.futures import Future
+from functools import wraps     # import from functools to prevent circular import exception
 
-from functools import wraps
+__all__ = ['measure', 'time_as_int', 'time_ms', 'sleep', 'time_us']
 
-__all__ = ['measure', 'time_as_int', 'time_ms']
+
+def sleep(x: float, abort_on_interrupt: bool = False) -> bool:
+    """
+    Sleep for given interval.
+
+    This won't be interrupted by KeyboardInterrupted, and always will sleep for given time interval.
+    This will return at once if x is negative
+
+    :param x: the interval to wait
+    :param abort_on_interrupt: whether to abort at once when KeyboardInterrupt is seen
+    :returns: whether the function has completed its sleep naturally. False is seen on
+        aborts thanks to KeyboardInterrupt only if abort_on_interrupt is True
+    """
+    if x < 0:
+        return
+
+    with measure() as measurement:
+        while measurement() < x:
+            try:
+                time.sleep(x - measurement())
+            except KeyboardInterrupt:
+                if abort_on_interrupt:
+                    return False
+                pass
+    return True
 
 
 def time_as_int() -> int:
@@ -31,14 +56,22 @@ def time_ms() -> int:
     try:
         return time.time_ns() // 1000000
     except AttributeError:
-        return int(time.time()*1000)
+        return int(time.time() * 1000)
 
 
 def time_us() -> int:
+    """
+    Syntactic sugar for
+
+    >>> from time import time
+    >>> int(time()*1000000)
+
+    This will try to use time.time_ns() if available
+    """
     try:
         return time.time_ns() // 1000
     except AttributeError:
-        return int(time.time()*1000000)
+        return int(time.time() * 1000000)
 
 
 class measure:
@@ -69,7 +102,8 @@ class measure:
     >>> def measuring(measurement_object: measure, *args, **kwargs):
     >>>     ...
 
-    This will also correctly work on methods, correctly inserting the measurement object after self/cls:
+    This will also correctly work on methods, correctly inserting the measurement object after
+    self/cls:
 
     >>> class Test:
     >>>     @measure()
@@ -91,8 +125,8 @@ class measure:
 
     Note that if you're using the decorator form, this object will be first copied and then
     passed to the function/future. This is to prevent undefined behaviour during multithreading.
-    Also, the timer that you pass to this function will be started/not started, depending on what you
-    set earlier. .reset() will be called on a copy of this object.
+    Also, the timer that you pass to this function will be started/not started, depending on what
+    you set earlier. .reset() will be called on a copy of this object.
 
     :param stop_on_stop: stop elapsing time upon calling .stop()/exiting the context manager.
         If this is set to False then .start() and .stop() won't work and calling them will raise a
@@ -203,6 +237,7 @@ class measure:
                                 return func(s, *args, **kwargs)
                         else:
                             return func(s, *args, **kwargs)
+
                     return inner
 
             return outer(fun)
